@@ -310,7 +310,7 @@ def srinterpolate( eneloss , plot=False):
 
 
 def get_sr_loss( SRIN , Emax=5.8, dmax=10 , unit="um" ):
-    print("\ni...       SRIN LOSS: Eini={}  t={} {}\n".format(Emax, dmax, unit) )
+    print("\ni... --------running---- SR.EXE LOSS: Eini={}  t={:.3f} {}".format(Emax, dmax, unit) )
     if SRIN=="":
         print("XXX...   SR.IN was not created, returns")
         return
@@ -423,14 +423,13 @@ def CheckSrimFiles():
     '''
 
     helpsrim="""
-============================================================
-    Installation help:
+====== SRIM Installation help: ========================================
     apt install wine
 
-    SRIM: ----------------------------------------------------
     SRIM 2013 can be downloaded from  http://www.srim.org/SRIM/SRIM-2013-Pro.e
     or better get a smaller version for multiple running copies http://www.srim.org/SRIM/SRIM-2013-Std.e
 
+    #======= run this to install SRIM =========== BEGIN
     cd /tmp
     wine notepad # may help to initialize ~/.wine/drive_c/...
     cd ~/.wine/drive_c/Program\ Files/
@@ -440,25 +439,33 @@ def CheckSrimFiles():
     wine SRIM-2013-Pro.e
     # all should be correctly extracted
     wine SRIM.exe
+    #======= run this to install SRIM =========== END
 
-    Here an error probably appear: import_dll Library MSVBVM50.DLL not found
+    # Here an error probably appear: import_dll Library MSVBVM50.DLL not found
+    # Following libraries are missing in ~/.wine/drive_c/windows/
+    #       152848  COMDLG32.OCX
+    #       244416  msflxgrd.ocx
+    #      1347344  MSVBVM50.DLL
+    #       212240  RICHTX32.OCX
+    #       224016  TABCTL32.OCX
 
-    Following libraries are missing in ~/.wine/drive_c/windows/
+    # If you find the file libs2013.tgz - try:
+    # find ~/.local/lib -iname "libs*.tgz"
 
-          152848  COMDLG32.OCX
-          244416  msflxgrd.ocx
-         1347344  MSVBVM50.DLL
-          212240  RICHTX32.OCX
-          224016  TABCTL32.OCX
-
-    If you find the file libs2013.tgz
-
-    cp  nuphy2/data/libs2013.tgz ~/.wine/drive_c/windows/system
+    # ====== enter the dir with libs and run ======BEGIN
+    cp  libs2013.tgz ~/.wine/drive_c/windows/system
     cd ~/.wine/drive_c/windows/system
     tar -xvzf libs2013.tgz
     cd ~/.wine/drive_c/Program\ Files/SRIM/
     wine SRIM.exe
+    # ===============================================END
 
+    # There can happen that locale produces numbers with decimal ",".
+    # Check it with
+    wine regedit
+    # see MyComputer/HKEY_CURRENT_USER/ControlPanel/International/sDecimal
+    # you may need to completely delete all your ~/.wine
+    # change locale to en_US.utf8 (or en_GB) and start 'wine notepad'
     """
     home = os.path.expanduser("~")
     paths=[home]
@@ -480,7 +487,7 @@ def CheckSrimFiles():
             for file in os.listdir( path ):
                 if file=='TRIM.exe':
                     RPATH=path
-                    print('+...  found SRIM.exe in ',path)
+                    # print('+...  found SRIM.exe in ',path)
     if RPATH is None:
         print("X... srim not found in ",paths)
         print(helpsrim)
@@ -963,7 +970,10 @@ def targ(  name, thick,   ion,  outerdens  , SRLINE ):
             mat[name]=[ eZ, isoto1.amu,  1., indivdisp[eZ], lattdisp[eZ],  heatsu ]
 
         #print('i...',name, 'MAT ... ',mat[name], '   "is gas"==',isgas)
-        print('    ',name, '  "is gas"==',isgas)
+        if isgas==0:
+            print('    ',name, '  is NOT a gas')
+        else:
+            print('    ',name, '  is a GAS')
         #print('!... ============= not correct ====== VERIFY INPUT in SRIM!')
 
 
@@ -1161,10 +1171,12 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
             print('i... JuPyter detected - vdislay initiated')
             silent=True #### PROBLEM with X in Jupyter?
 #################################################### PROCESS WITH WAIT ####
+
         if silent:
-            print("############### VDISPLAY #########################start")
+            print("############### VDISPLAY ####################start r_srim")
             vdisplay = Xvfb(width=1280, height=740, colordepth=16)
             vdisplay.start()
+
         def worker():
             process = subprocess.Popen('wine TRIM.exe'.split(),
                                        stdout=subprocess.DEVNULL,
@@ -1226,7 +1238,7 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
         if silent:
             vdisplay.stop() #
             #print()
-            print("\n############### VDISPLAY #########################stop")
+            print("\n############### VDISPLAY ###################stop r_srim")
 #################################################### PROCESS WITH WAIT ####
 
 
@@ -1331,7 +1343,7 @@ def run_srim(RPATH, TRIMIN , strip=True, silent=False , nmax=1 ):
 # in perl:
 #     - convolution with nehomogenities
 #     - analyse range
-#     - gpressTAB  STD    my $densNEW=$densSTD  *  $p/1013.25  *   273.15/$T;
+#     - gpressTAB  STD    my $densNEW=$densSTD  *  $p/101.325  *   273.15/$T;
 #     -   if ( $args{"fthick"} >0){           amoeba
 
 
@@ -1370,15 +1382,15 @@ def material_density( matnam ):
     #print('DDD...  compounds keys: ',srcomp.material_text.keys()  )
     mm_amu=1.0  # NONSENSE
     myisotope=None
-    print("matnam in material_density /{}/".format(matnam))
+    # print("matnam in material_density /{}/".format(matnam))
 
     if matnam in srcomp.material_text.keys():
-        print('F... FOUND in compounds')
+        print('F... ',matnam,'was FOUND in compounds')
         dens=srcomp.get_density( matnam  )
         print('i... FOUND density from compounds=',dens)  # mm_amu ???
         # mm_amu determined probably somewhere in SRIM.... # i dont need
     elif matnam.title() in elements:   # ELEMENT ARE AWAYS Capitalized
-        print('F...  ',matnam,' FOUND in elements ')
+        print('F...  ',matnam,' was FOUND in elements ')
         CC=matnam.title()
         #print(CC,type(CC))
         zzz=elements.index(  matnam.title() )
@@ -1433,7 +1445,7 @@ def isitGas( material ):
 # get_thick_rho  ......  I extract the part
 #         return   thick [ug/cm2] and rho g/cm3
 #####################################
-def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):   #convert properly um and find rho
+def get_thick_rho( material,  thick, rho ,Pressure=101325, Temperature=273):   #convert properly um and find rho
     """
     takes all thicknesses   um  ug:
 
@@ -1467,21 +1479,21 @@ def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):
         """
         trim assumes the target as STP before 1982
         T=273.15 K
-        p=1013.25 kPa
+        p=101.325 kPa           =>>>>     p=101.325 kPa   10^5 !!!!!
         SRIMHelp/helpTR23.rtf
         """
-        R=1013.25e+3/273.15/rho
+        R=101.325e+3/273.15/rho
         rho2=Pressure/R/Temperature
-        print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+        print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     elif material.title() in elements:
         #print("D... rho - elements")
         eZ=elements.index(material.title())
         print("D... rho - elements  eZ={:d}".format(eZ))
         #print(gas)
         if gas[ eZ ]==1:
-            R=1013.25e+3/273.15/rho
+            R=101.325e+3/273.15/rho
             rho2=Pressure/R/Temperature
-            print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+            print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     else: # could be also a gaseous  isotope
         #print('D... maybe gaseous isotope?')
         if isotope is None:
@@ -1497,9 +1509,9 @@ def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):
             eZ=isotope.Z
             if gas[ eZ ]==1:
                 print('i... GAS')
-                R=1013.25e+3/273.15/rho
+                R=101.325e+3/273.15/rho
                 rho2=Pressure/R/Temperature
-                print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+                print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     rho=rho2
     #print("D... rho WAS deduced")
     # THICKNESS TO mgcm2:    ##### MY UNIT WILL BE mg/cm2
@@ -1550,13 +1562,13 @@ def get_thick_rho( material,  thick, rho ,Pressure=1013250, Temperature=273):
 #
 #            prasarna  ......... incomming0
 ########################################
-def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number, Pressure=1013250, Temperature=273):
+def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number, Pressure=101325, Temperature=273):
     '''
     Here I prepare materials:  single layers
     '''
     print('D... preparing TRIMIN:', material, thick, '  rho_ini=',rho, '-------------')
     #print('D... PV/T density:')
-    print("material trimin {}".format( material) )
+    # print("material trimin {}".format( material) )
     rho=float(rho)
     isotope=None
     if rho==0:
@@ -1571,20 +1583,20 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
         """
         trim assumes the target as STP before 1982
         T=273.15 K
-        p=1013.25 kPa
+        p=101.325 kPa
         SRIMHelp/helpTR23.rtf
         """
-        R=1013.25e+3/273.15/rho
+        R=101.325e+3/273.15/rho
         rho2=Pressure/R/Temperature
-        print('i...rho at STD (0deg,1013kPa)=',rho,' NEW now=',rho2)
+        print('i...rho at STD (0deg,101.3kPa)=',rho,' NEW now=',rho2)
     elif material.title() in elements:
         print("D... rho - elements")
         eZ=elements.index(material.title())
         print("D... rho - elements  eZ=",eZ)
         if gaseous[ eZ ]==1:
-            R=1013.25e+3/273.15/rho
+            R=101.325e+3/273.15/rho
             rho2=Pressure/R/Temperature
-            print('i...rho at STD (0deg,1013kPa)=',rho,' now=',rho2)
+            print('i...rho at STD (0deg,101.3kPa)=',rho,' now=',rho2)
     else: # could be also a gaseous  isotope
         #print('D... maybe gaseous isotope?')
         try:
@@ -1597,9 +1609,9 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
             eZ=isotope.Z
             if gaseous[ eZ ]==1:
                 print('i... GAS')
-                R=1013.25e+3/273.15/rho
+                R=101.325e+3/273.15/rho
                 rho2=Pressure/R/Temperature
-                print('i...rho at STD (0deg,1013kPa)=',rho,' now=',rho2)
+                print('i...rho at STD (0deg,101.3kPa)=',rho,' now=',rho2)
     rho=rho2
 
     #print("DDD... rho deduced")============================================
@@ -1644,7 +1656,7 @@ def prepare_trimin( material,  thick,  rho  , incomming0 , Eini, angle, number,
 
 #--------------------------------------------------- START OF OLD NUPHY BIN
 def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness="0ug",
-                  material="c12", Pressure=1013.25e+3, Temperature=273.15,
+                  material="c12", Pressure=101.325e+3, Temperature=273.15,
                   silent = False, fwhm=0, Store="" ):
 
     #print("1=============/{}/==========".format(Store))
@@ -1978,7 +1990,7 @@ def old_nuphy_bin( incomming=None, energy=5.8, number=100, density=0, thickness=
 def main( i="", m="" , t="", e="", a="",  n=100,
           dens=0,              # override density
           f=0,                 # fwhm of the detector
-          p=1013.25, k=273.15, #k =temp in K
+          p=101325, k=273.15, #k =temp in K
 #          h="",                #
           w="",
           s = False,           # silent
@@ -1997,7 +2009,7 @@ def main( i="", m="" , t="", e="", a="",  n=100,
     """
     global print
     print=super_print(debug)(print)
-
+    print("\n")
 
     ipath=CheckSrimFiles()
     # -- in commandline it may be a tuple: force to str
@@ -2027,7 +2039,7 @@ def main( i="", m="" , t="", e="", a="",  n=100,
 
         if isinstance(w,bool): fail(Bcolors.WARNING+"? -w filename.h5 is expected")
 
-        if w=="": print(Bcolors.WARNING+"? not saving.... -w filename.h5" + Bcolors.ENDC)
+        if w=="": print(Bcolors.WARNING+"i... not saving.... -w filename.h5" + Bcolors.ENDC)
         #
         #
         print(Bcolors.OKGREEN + "D... PROJECTILE   :", i + Bcolors.ENDC )
@@ -2037,13 +2049,17 @@ def main( i="", m="" , t="", e="", a="",  n=100,
         print( Bcolors.OKGREEN +  "D... TARGET       :", m + Bcolors.ENDC )
         #nu2.pprint()
         print( Bcolors.OKGREEN +  "D... Thickness   =:", t + Bcolors.ENDC)
+
+
+
+        print( Bcolors.OKGREEN +  "i... to run without SRIM screen:  -s" + Bcolors.ENDC)
         # print( Bcolors.OKGREEN +  "D... OUTGOING 1   :" , m+ Bcolors.ENDC)
         #nu3.pprint()
 
         # print( Bcolors.BOLD +  "D... Angle       =:", str(a) + Bcolors.ENDC)
         # print( Bcolors.BOLD +  "D... Excitation  =:", x,"MeV"+ Bcolors.ENDC )
         #  print( Bcolors.BOLD +  "D... Outputfile,V=:", "None"+ Bcolors.ENDC )
-
+        print("\n")
         old_nuphy_bin(incomming=i, energy=e, number=n,
                       density=dens,
                       thickness=t,
